//
// "uman" module - http://atoms.scilab.org/toolboxes/uman
// Copyright (C) - 2015-2019 - Samuel GOUGEON
// 
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING.  
// The terms are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.txt
//
// =================================================================================
//  Unit tests for "uman ... g.."
//
// "uman" online page: http://atoms.scilab.org/toolboxes/uman
//
// <-- TEST WITH GRAPHIC -->   // we need the JVM
// <-- INTERACTIVE TEST -->

// "g" option
// ==========
// case-sensitive entry is supported
uman type g    
uman Type g    
uman cumsum g
uman CUMSUM g
uman strstr g
uman Strstr g  // displays 'uman: "Strstr" has no dedicated page.'
               //  and smoothly redirects to 'strstr'

uman % g       // Symbols are directly targeted, while help % == help symbols
uman .*. g     // == help kron, while help .*. == help symbols
uman files g   // uman shortcuts are active => summary of files functions
uman %i sg     // The "s" option is active => summary of %i section
uman polyval g // uman ex2in redirections are active => horner() page
uman end xg    // uman external priorization is active => $'s page targeted
uman uman g    // pages of loaded ATOMS (or contrib) modules are available
uman cshift g  // feature from FileExchange
               // => only displays "uman cshift w // should work [FileExchange]."
uman gpib g    // feature an external ressource
               // => only displays "uman gpib wg // should work."

// Language switches are active:
// close the help browser
uman linspace glru   // linspace() page in Russian
// close the help browser
uman linspace glja   // linspace() page in Japanese
 
// With a local function
// ---------------------
function [b, c] = myfun(a)
    // myfun() local function defined for testing uman .. g
    // a: first input
    // b: first output
    // c: second output
    b = a;
    c = %pi;
endfunction
uman myfun g    // The help browser opens with the list of help entries showing
                //  the "myfun" item in their text.
                //  + myfun() heading comments are displayed in the console.
clear myfun

// With an item matching no acknowledged help entry:
// ------------------------------------------------
uman myfun g    // "uman: 'myfun' has no dedicated page." displayed in console.
                // + help browser opened with the list of help entries showing
                //  the "myfun" item in their text.

// With an ATOMS package
// ---------------------
try
    uman atoms d           // List of ATOMS functions
    yn = atomsIsInstalled("plotlib"); 
    atomsInstall plotlib ; // Let's install Plotlib.
    atomsIsLoaded plotlib  // => %F
    uman plot dexg         // the help browser called with "g" does not come, 
                            //  because Plotlib is not loaded. Then, instead,
                            //  its page is displayed in the console.
    if ~yn, atomsRemove("plotlib"), end    // cleaning after the example
catch
end
